@@ -121,7 +121,8 @@ class IconFactory:
         colors = CONFIG['icon.colors'].split(',')
         cls.register_icon(iconname)
         if iconname in ("tryton-open", "tryton-launch", "tryton-cancel",
-            "tryton-ok", "tryton-go-next", "tryton-info", "tryton-forward"):
+            "tryton-ok", "tryton-go-next", "tryton-info",
+            "tryton-forward", "tryton-back", "tryton-refresh"):
             iconname = iconname.replace("tryton","gnuhealth")
         if iconname not in cls._pixbufs[(size, badge)]:
             if iconname in cls._icons:
