@@ -415,7 +415,12 @@ class DBLogin(object):
         self.dialog.vbox.pack_start(grid, expand=True, fill=True, padding=0)
 
         image = Gtk.Image()
-        image.set_from_file(os.path.join(PIXMAPS_DIR, BANNER))
+        # Use custom banner if set in the custom_banner param
+        if (CONFIG['client.banner']):
+            image.set_from_file(CONFIG['client.banner'])
+        else:
+            image.set_from_file(os.path.join(PIXMAPS_DIR, BANNER))
+
         image.set_valign(Gtk.Align.START)
         overlay = Gtk.Overlay()
         overlay.add(image)
